@@ -1,8 +1,6 @@
 'use strict';
 
-let nodemailer = require('nodemailer');
-
-/* --- Select AWS SDK version by uncommenting correct version --- */
+let nodemailer = require('../lib/nodemailer');
 
 let aws = require('@aws-sdk/client-ses');
 
