@@ -58,6 +58,8 @@ class SMTPConnection extends EventEmitter {
         this.port = Number(this.options.port) || (this.secureConnection ? 465 : 587);
         this.host = this.options.host || 'localhost';
 
+        this.servername = this.options.servername ? this.options.servername : !net.isIP(this.host) ? this.host : false;
+
         this.allowInternalNetworkInterfaces = this.options.allowInternalNetworkInterfaces || false;
 
         if (typeof this.options.secure === 'undefined' && this.port === 465) {
@@ -241,6 +243,8 @@ class SMTPConnection extends EventEmitter {
         if (this.options.connection) {
             // connection is already opened
             this._socket = this.options.connection;
+            setupConnectionHandlers();
+
             if (this.secureConnection && !this.alreadySecured) {
                 setImmediate(() =>
                     this._upgradeConnection(err => {
@@ -296,6 +300,12 @@ class SMTPConnection extends EventEmitter {
                     opts[key] = this.options.tls[key];
                 });
             }
+
+            // ensure servername for SNI
+            if (this.servername && !opts.servername) {
+                opts.servername = this.servername;
+            }
+
             return shared.resolveHostname(opts, (err, resolved) => {
                 if (err) {
                     return setImmediate(() => this._onError(err, 'EDNS', false, 'CONN'));
@@ -434,7 +444,7 @@ class SMTPConnection extends EventEmitter {
         }
 
         if (this._authMethod !== 'XOAUTH2' && (!this._auth.credentials || !this._auth.credentials.user || !this._auth.credentials.pass)) {
-            if (this._auth.user && this._auth.pass) {
+            if ((this._auth.user && this._auth.pass) || this.customAuth.has(this._authMethod)) {
                 this._auth.credentials = {
                     user: this._auth.user,
                     pass: this._auth.pass,
@@ -620,6 +630,15 @@ class SMTPConnection extends EventEmitter {
         let startTime = Date.now();
         this._setEnvelope(envelope, (err, info) => {
             if (err) {
+                // create passthrough stream to consume to prevent OOM
+                let stream = new PassThrough();
+                if (typeof message.pipe === 'function') {
+                    message.pipe(stream);
+                } else {
+                    stream.write(message);
+                    stream.end();
+                }
+
                 return callback(err);
             }
             let envelopeTime = Date.now();
@@ -904,6 +923,11 @@ class SMTPConnection extends EventEmitter {
             opts[key] = this.options.tls[key];
         });
 
+        // ensure servername for SNI
+        if (this.servername && !opts.servername) {
+            opts.servername = this.servername;
+        }
+
         this.upgrading = true;
         // tls.connect is not an asynchronous function however it may still throw errors and requires to be wrapped with try/catch
         try {
