@@ -1,10 +1,7 @@
-/* eslint no-unused-expressions:0, prefer-arrow-callback:0 */
-/* globals afterEach, beforeEach, describe, it */
-
 'use strict';
 
-const chai = require('chai');
-const expect = chai.expect;
+const { describe, it, beforeEach, afterEach } = require('node:test');
+const assert = require('node:assert/strict');
 
 //let http = require('http');
 const nmfetch = require('../../lib/fetch');
@@ -13,8 +10,6 @@ const https = require('https');
 const zlib = require('zlib');
 const PassThrough = require('stream').PassThrough;
 
-chai.config.includeStack = true;
-
 const HTTP_PORT = 19998;
 const HTTPS_PORT = 19993;
 
@@ -67,13 +62,11 @@ const httpsOptions = {
         '-----END CERTIFICATE-----'
 };
 
-describe('NMFetch Tests', function () {
-    this.timeout(50 * 1000); // eslint-disable-line no-invalid-this
-
+describe('NMFetch Tests', { timeout: 50 * 1000 }, () => {
     let httpServer, httpsServer;
 
-    beforeEach(function (done) {
-        httpServer = http.createServer(function (req, res) {
+    beforeEach((t, done) => {
+        httpServer = http.createServer((req, res) => {
             switch (req.url) {
                 case '/redirect6':
                     res.writeHead(302, {
@@ -166,13 +159,13 @@ describe('NMFetch Tests', function () {
 
                 case '/post': {
                     let body = [];
-                    req.on('readable', function () {
+                    req.on('readable', () => {
                         let chunk;
                         while ((chunk = req.read()) !== null) {
                             body.push(chunk);
                         }
                     });
-                    req.on('end', function () {
+                    req.on('end', () => {
                         res.writeHead(200, {
                             'Content-Type': 'text/plain'
                         });
@@ -189,258 +182,258 @@ describe('NMFetch Tests', function () {
             }
         });
 
-        httpsServer = https.createServer(httpsOptions, function (req, res) {
+        httpsServer = https.createServer(httpsOptions, (req, res) => {
             res.writeHead(200, {
                 'Content-Type': 'text/plain'
             });
             res.end('Hello World HTTPS\n');
         });
 
-        httpServer.listen(HTTP_PORT, function () {
+        httpServer.listen(HTTP_PORT, () => {
             httpsServer.listen(HTTPS_PORT, done);
         });
     });
 
-    afterEach(function (done) {
-        httpServer.close(function () {
+    afterEach((t, done) => {
+        httpServer.close(() => {
             httpsServer.close(done);
         });
     });
 
-    it('should fetch HTTP data', function (done) {
+    it('should fetch HTTP data', (t, done) => {
         let req = nmfetch('http://localhost:' + HTTP_PORT);
         let buf = [];
-        req.on('data', function (chunk) {
+        req.on('data', chunk => {
             buf.push(chunk);
         });
-        req.on('end', function () {
-            expect(Buffer.concat(buf).toString()).to.equal('Hello World HTTP\n');
+        req.on('end', () => {
+            assert.strictEqual(Buffer.concat(buf).toString(), 'Hello World HTTP\n');
             done();
         });
     });
 
-    it('should fetch HTTPS data', function (done) {
+    it('should fetch HTTPS data', (t, done) => {
         let req = nmfetch('https://localhost:' + HTTPS_PORT);
         let buf = [];
-        req.on('data', function (chunk) {
+        req.on('data', chunk => {
             buf.push(chunk);
         });
-        req.on('end', function () {
-            expect(Buffer.concat(buf).toString()).to.equal('Hello World HTTPS\n');
+        req.on('end', () => {
+            assert.strictEqual(Buffer.concat(buf).toString(), 'Hello World HTTPS\n');
             done();
         });
     });
 
-    it('should fetch HTTP data with redirects', function (done) {
+    it('should fetch HTTP data with redirects', (t, done) => {
         let req = nmfetch('http://localhost:' + HTTP_PORT + '/redirect3');
         let buf = [];
-        req.on('data', function (chunk) {
+        req.on('data', chunk => {
             buf.push(chunk);
         });
-        req.on('end', function () {
-            expect(Buffer.concat(buf).toString()).to.equal('Hello World HTTP\n');
+        req.on('end', () => {
+            assert.strictEqual(Buffer.concat(buf).toString(), 'Hello World HTTP\n');
             done();
         });
     });
 
-    it('should return error for too many redirects', function (done) {
+    it('should return error for too many redirects', (t, done) => {
         let req = nmfetch('http://localhost:' + HTTP_PORT + '/redirect6');
         let buf = [];
-        req.on('data', function (chunk) {
+        req.on('data', chunk => {
             buf.push(chunk);
         });
-        req.on('error', function (err) {
-            expect(err).to.exist;
+        req.on('error', err => {
+            assert.ok(err);
             done();
         });
-        req.on('end', function () {});
+        req.on('end', () => {});
     });
 
-    it('should fetch HTTP data with custom redirect limit', function (done) {
+    it('should fetch HTTP data with custom redirect limit', (t, done) => {
         let req = nmfetch('http://localhost:' + HTTP_PORT + '/redirect3', {
             maxRedirects: 3
         });
         let buf = [];
-        req.on('data', function (chunk) {
+        req.on('data', chunk => {
             buf.push(chunk);
         });
-        req.on('end', function () {
-            expect(Buffer.concat(buf).toString()).to.equal('Hello World HTTP\n');
+        req.on('end', () => {
+            assert.strictEqual(Buffer.concat(buf).toString(), 'Hello World HTTP\n');
             done();
         });
     });
 
-    it('should return error for custom redirect limit', function (done) {
+    it('should return error for custom redirect limit', (t, done) => {
         let req = nmfetch('http://localhost:' + HTTP_PORT + '/redirect3', {
             maxRedirects: 2
         });
         let buf = [];
-        req.on('data', function (chunk) {
+        req.on('data', chunk => {
             buf.push(chunk);
         });
-        req.on('error', function (err) {
-            expect(err).to.exist;
+        req.on('error', err => {
+            assert.ok(err);
             done();
         });
-        req.on('end', function () {});
+        req.on('end', () => {});
     });
 
-    it('should return disable redirects', function (done) {
+    it('should return disable redirects', (t, done) => {
         let req = nmfetch('http://localhost:' + HTTP_PORT + '/redirect1', {
             maxRedirects: 0
         });
         let buf = [];
-        req.on('data', function (chunk) {
+        req.on('data', chunk => {
             buf.push(chunk);
         });
-        req.on('error', function (err) {
-            expect(err).to.exist;
+        req.on('error', err => {
+            assert.ok(err);
             done();
         });
-        req.on('end', function () {});
+        req.on('end', () => {});
     });
 
-    it('should unzip compressed HTTP data', function (done) {
+    it('should unzip compressed HTTP data', (t, done) => {
         let req = nmfetch('http://localhost:' + HTTP_PORT + '/gzip');
         let buf = [];
-        req.on('data', function (chunk) {
+        req.on('data', chunk => {
             buf.push(chunk);
         });
-        req.on('end', function () {
-            expect(Buffer.concat(buf).toString()).to.equal('Hello World HTTP\n');
+        req.on('end', () => {
+            assert.strictEqual(Buffer.concat(buf).toString(), 'Hello World HTTP\n');
             done();
         });
     });
 
-    it('should return error for unresolved host', function (done) {
+    it('should return error for unresolved host', (t, done) => {
         let req = nmfetch('http://asfhaskhhgbjdsfhgbsdjgk');
         let buf = [];
-        req.on('data', function (chunk) {
+        req.on('data', chunk => {
             buf.push(chunk);
         });
-        req.on('error', function (err) {
-            expect(err).to.exist;
+        req.on('error', err => {
+            assert.ok(err);
             done();
         });
-        req.on('end', function () {});
+        req.on('end', () => {});
     });
 
-    it('should return error for invalid status', function (done) {
+    it('should return error for invalid status', (t, done) => {
         let req = nmfetch('http://localhost:' + HTTP_PORT + '/invalid');
         let buf = [];
-        req.on('data', function (chunk) {
+        req.on('data', chunk => {
             buf.push(chunk);
         });
-        req.on('error', function (err) {
-            expect(err).to.exist;
+        req.on('error', err => {
+            assert.ok(err);
             done();
         });
-        req.on('end', function () {});
+        req.on('end', () => {});
     });
 
-    it('should allow invalid status', function (done) {
+    it('should allow invalid status', (t, done) => {
         let req = nmfetch('http://localhost:' + HTTP_PORT + '/invalid', {
             allowErrorResponse: true
         });
         let buf = [];
-        req.on('data', function (chunk) {
+        req.on('data', chunk => {
             buf.push(chunk);
         });
-        req.on('error', function (err) {
-            expect(err).to.not.exist;
+        req.on('error', err => {
+            assert.ok(!err);
         });
-        req.on('end', function () {
-            expect(req.statusCode).to.equal(500);
-            expect(Buffer.concat(buf).toString()).to.equal('Hello World HTTP\n');
+        req.on('end', () => {
+            assert.strictEqual(req.statusCode, 500);
+            assert.strictEqual(Buffer.concat(buf).toString(), 'Hello World HTTP\n');
             done();
         });
     });
 
-    it('should return error for invalid url', function (done) {
+    it('should return error for invalid url', (t, done) => {
         let req = nmfetch('http://localhost:99999999/');
         let buf = [];
-        req.on('data', function (chunk) {
+        req.on('data', chunk => {
             buf.push(chunk);
         });
-        req.on('error', function (err) {
-            expect(err).to.exist;
+        req.on('error', err => {
+            assert.ok(err);
             done();
         });
-        req.on('end', function () {});
+        req.on('end', () => {});
     });
 
-    it('should return timeout error', function (done) {
+    it('should return timeout error', (t, done) => {
         let req = nmfetch('http://localhost:' + HTTP_PORT + '/forever', {
             timeout: 1000
         });
         let buf = [];
-        req.on('data', function (chunk) {
+        req.on('data', chunk => {
             buf.push(chunk);
         });
-        req.on('error', function (err) {
-            expect(err).to.exist;
+        req.on('error', err => {
+            assert.ok(err);
             done();
         });
-        req.on('end', function () {});
+        req.on('end', () => {});
     });
 
-    it('should handle basic HTTP auth', function (done) {
+    it('should handle basic HTTP auth', (t, done) => {
         let req = nmfetch('http://user:pass@localhost:' + HTTP_PORT + '/auth');
         let buf = [];
-        req.on('data', function (chunk) {
+        req.on('data', chunk => {
             buf.push(chunk);
         });
-        req.on('end', function () {
-            expect(Buffer.concat(buf).toString()).to.equal('user:pass');
+        req.on('end', () => {
+            assert.strictEqual(Buffer.concat(buf).toString(), 'user:pass');
             done();
         });
     });
 
     if (!/^0\.10\./.test(process.versions.node)) {
         // disabled for node 0.10
-        it('should return error for invalid protocol', function (done) {
+        it('should return error for invalid protocol', (t, done) => {
             let req = nmfetch('http://localhost:' + HTTPS_PORT);
             let buf = [];
-            req.on('data', function (chunk) {
+            req.on('data', chunk => {
                 buf.push(chunk);
             });
-            req.on('error', function (err) {
-                expect(err).to.exist;
+            req.on('error', err => {
+                assert.ok(err);
                 done();
             });
-            req.on('end', function () {});
+            req.on('end', () => {});
         });
     }
 
-    it('should set cookie value', function (done) {
+    it('should set cookie value', (t, done) => {
         let req = nmfetch('http://localhost:' + HTTP_PORT + '/cookie', {
             cookie: 'test=pest'
         });
         let buf = [];
-        req.on('data', function (chunk) {
+        req.on('data', chunk => {
             buf.push(chunk);
         });
-        req.on('end', function () {
-            expect(Buffer.concat(buf).toString()).to.equal('test=pest');
+        req.on('end', () => {
+            assert.strictEqual(Buffer.concat(buf).toString(), 'test=pest');
             done();
         });
     });
 
-    it('should set user agent', function (done) {
+    it('should set user agent', (t, done) => {
         let req = nmfetch('http://localhost:' + HTTP_PORT + '/ua', {
             userAgent: 'nodemailer-fetch'
         });
         let buf = [];
-        req.on('data', function (chunk) {
+        req.on('data', chunk => {
             buf.push(chunk);
         });
-        req.on('end', function () {
-            expect(Buffer.concat(buf).toString()).to.equal('nodemailer-fetch');
+        req.on('end', () => {
+            assert.strictEqual(Buffer.concat(buf).toString(), 'nodemailer-fetch');
             done();
         });
     });
 
-    it('should post data', function (done) {
+    it('should post data', (t, done) => {
         let req = nmfetch('http://localhost:' + HTTP_PORT + '/post', {
             method: 'post',
             body: {
@@ -449,16 +442,16 @@ describe('NMFetch Tests', function () {
             }
         });
         let buf = [];
-        req.on('data', function (chunk) {
+        req.on('data', chunk => {
             buf.push(chunk);
         });
-        req.on('end', function () {
-            expect(Buffer.concat(buf).toString()).to.equal('hello=world%20%F0%9F%98%AD&another=value');
+        req.on('end', () => {
+            assert.strictEqual(Buffer.concat(buf).toString(), 'hello=world%20%F0%9F%98%AD&another=value');
             done();
         });
     });
 
-    it('should post stream data', function (done) {
+    it('should post stream data', (t, done) => {
         let body = new PassThrough();
         let data = Buffer.from('hello=world%20%F0%9F%98%AD&another=value');
 
@@ -467,16 +460,16 @@ describe('NMFetch Tests', function () {
             body
         });
         let buf = [];
-        req.on('data', function (chunk) {
+        req.on('data', chunk => {
             buf.push(chunk);
         });
-        req.on('end', function () {
-            expect(Buffer.concat(buf).toString()).to.equal(data.toString());
+        req.on('end', () => {
+            assert.strictEqual(Buffer.concat(buf).toString(), data.toString());
             done();
         });
 
         let pos = 0;
-        let writeNext = function () {
+        let writeNext = () => {
             if (pos >= data.length) {
                 return body.end();
             }
@@ -488,20 +481,20 @@ describe('NMFetch Tests', function () {
         setImmediate(writeNext);
     });
 
-    it('should return error for invalid cert', function (done) {
+    it('should return error for invalid cert', (t, done) => {
         let req = nmfetch('https://localhost:' + HTTPS_PORT, {
             tls: {
                 rejectUnauthorized: true
             }
         });
         let buf = [];
-        req.on('data', function (chunk) {
+        req.on('data', chunk => {
             buf.push(chunk);
         });
-        req.on('error', function (err) {
-            expect(err).to.exist;
+        req.on('error', err => {
+            assert.ok(err);
             done();
         });
-        req.on('end', function () {});
+        req.on('end', () => {});
     });
 });
