@@ -1,18 +1,13 @@
-/* eslint no-unused-expressions:0, prefer-arrow-callback: 0 */
-/* globals describe, it */
-
 'use strict';
 
+const { describe, it } = require('node:test');
+const assert = require('node:assert/strict');
 const libqp = require('libqp');
 const qp = require('../../lib/qp');
-const chai = require('chai');
-const expect = chai.expect;
 const crypto = require('crypto');
 const fs = require('fs');
 
-chai.config.includeStack = true;
-
-describe('Quoted-Printable Tests', function () {
+describe('Quoted-Printable Tests', () => {
     let encodeFixtures = [
         ['abcd= ÕÄÖÜ', 'abcd=3D =C3=95=C3=84=C3=96=C3=9C'],
         ['foo bar  ', 'foo bar =20'],
@@ -32,32 +27,32 @@ describe('Quoted-Printable Tests', function () {
         '12345678=\r\n90123456=\r\n78=20=20=\r\n90\r\n=C3=B5=\r\n=C3=A4=\r\n=C3=B6=\r\n=C3=BC=\r\n=C3=B5=\r\n=C3=A4=\r\n=C3=B6=\r\n=C3=BC=\r\n=C3=B5=\r\n=C3=A4=\r\n=C3=B6=\r\n=C3=BC=\r\n=C3=B5=\r\n=C3=A4=\r\n=C3=B6=\r\n=C3=BC=\r\n=C3=B5=\r\n=C3=A4=\r\n=C3=B6=\r\n=C3=BC=\r\n=C3=B5=\r\n=C3=A4=\r\n=C3=B6=\r\n=C3=BC=\r\n=C3=B5=\r\n=C3=A4=\r\n=C3=B6=\r\n=C3=BC=\r\n=C3=B5=\r\n=C3=A4=\r\n=C3=B6=\r\n=C3=BC=\r\n=20anoth=\r\ner=20lin=\r\ne=20=3D=\r\n=3D=3D=20'
     ];
 
-    describe('#encode', function () {
-        it('shoud encode UTF-8 string to QP', function () {
-            encodeFixtures.forEach(function (test) {
-                expect(qp.encode(test[0])).to.equal(test[1]);
+    describe('#encode', () => {
+        it('shoud encode UTF-8 string to QP', () => {
+            encodeFixtures.forEach(test => {
+                assert.strictEqual(qp.encode(test[0]), test[1]);
             });
         });
 
-        it('shoud encode Buffer to QP', function () {
-            expect(qp.encode(Buffer.from([0x00, 0x01, 0x02, 0x20, 0x03]))).to.equal('=00=01=02 =03');
+        it('shoud encode Buffer to QP', () => {
+            assert.strictEqual(qp.encode(Buffer.from([0x00, 0x01, 0x02, 0x20, 0x03])), '=00=01=02 =03');
         });
     });
 
-    describe('#wrap', function () {
-        it('should wrap long QP encoded lines', function () {
-            wrapFixtures.forEach(function (test) {
-                expect(qp.wrap(test[0], 20)).to.equal(test[1]);
+    describe('#wrap', () => {
+        it('should wrap long QP encoded lines', () => {
+            wrapFixtures.forEach(test => {
+                assert.strictEqual(qp.wrap(test[0], 20), test[1]);
             });
         });
 
-        it('should wrap line ending with <CR>', function () {
-            expect(qp.wrap('alfa palfa kalfa ralfa\r', 10)).to.equal('alfa palf=\r\na kalfa =\r\nralfa\r');
+        it('should wrap line ending with <CR>', () => {
+            assert.strictEqual(qp.wrap('alfa palfa kalfa ralfa\r', 10), 'alfa palf=\r\na kalfa =\r\nralfa\r');
         });
     });
 
-    describe('QP Streams', function () {
-        it('should transform incoming bytes to QP', function (done) {
+    describe('QP Streams', () => {
+        it('should transform incoming bytes to QP', (t, done) => {
             let encoder = new qp.Encoder({
                 lineLength: 9
             });
@@ -67,23 +62,23 @@ describe('Quoted-Printable Tests', function () {
                 buf = [],
                 buflen = 0;
 
-            encoder.on('data', function (chunk) {
+            encoder.on('data', chunk => {
                 buf.push(chunk);
                 buflen += chunk.length;
             });
 
-            encoder.on('end', function (chunk) {
+            encoder.on('end', chunk => {
                 if (chunk) {
                     buf.push(chunk);
                     buflen += chunk.length;
                 }
                 buf = Buffer.concat(buf, buflen);
 
-                expect(buf.toString()).to.equal(streamFixture[1]);
+                assert.strictEqual(buf.toString(), streamFixture[1]);
                 done();
             });
 
-            let sendNextByte = function () {
+            let sendNextByte = () => {
                 if (i >= bytes.length) {
                     return encoder.end();
                 }
@@ -96,7 +91,7 @@ describe('Quoted-Printable Tests', function () {
             sendNextByte();
         });
 
-        it('should transform incoming bytes to QP and back', function (done) {
+        it('should transform incoming bytes to QP and back', (t, done) => {
             let decoder = new libqp.Decoder();
             let encoder = new qp.Encoder();
             let file = fs.createReadStream(__dirname + '/fixtures/alice.txt');
@@ -106,21 +101,21 @@ describe('Quoted-Printable Tests', function () {
 
             file.pipe(encoder).pipe(decoder);
 
-            file.on('data', function (chunk) {
+            file.on('data', chunk => {
                 fhash.update(chunk);
             });
 
-            file.on('end', function () {
+            file.on('end', () => {
                 fhash = fhash.digest('hex');
             });
 
-            decoder.on('data', function (chunk) {
+            decoder.on('data', chunk => {
                 dhash.update(chunk);
             });
 
-            decoder.on('end', function () {
+            decoder.on('end', () => {
                 dhash = dhash.digest('hex');
-                expect(fhash).to.equal(dhash);
+                assert.strictEqual(fhash, dhash);
                 done();
             });
         });
